akhdefo_functions.Time_Series — Akhdefo software documentation

# akhdefo_functions.Time_Series

akhdefo_functions.Time_Series(stacked_raster_EW='', stacked_raster_NS='', velocity_points='', dates_name='', output_folder='', outputFilename='', rasteriz_mean_products=True, std=1, VEL_Scale='year')

  This program uses candiate velocity points from stackprep function and performs linear interpolation in time-domain to calibrate stacked velocity. Additionally produces corrected timeseries velocity(daily) in a shapefile.

  ## Parameters

  stacked_raster_EW : str

  stacked_raster_NS : str

  velocity_pointsstr

    Velcity Candidate points

  dates_namestr

    text file include name of each date in format YYYYMMDD

  output_folder : str

  outputFilename : str

  ## Returns

  Time-series shape file of velocity and direction EW, NS, and 2D(resultant Velocity and direction)